searchData={"items":[{"type":"module","title":"Ht16k33Multi","doc":"`Ht16k33Multi` is a library for controlling one or more `Ht16k33` microchips,\nwhich are commonly used to drive 7-segment displays, such as these shown below:\n\n![Image of Ht16k33 7-segment display](assets/ht16k33multi-7-segment-love-elixir.jpg)","ref":"Ht16k33Multi.html"},{"type":"module","title":"Features - Ht16k33Multi","doc":"The main features of `Ht16k33Multi` include:\n\n- Displaying numbers on a 7-segment display\n- Displaying words using a special 7-segment font\n- Supporting multiple displays (hence the \"multi\" in the library name).\n  You can easily chain multiple `Ht16k33` devices to display full sentences or other content across them.\n- Utilizing the built-in blinking and dimming features of the `Ht16k33` microchip","ref":"Ht16k33Multi.html#module-features"},{"type":"module","title":"Usage - Ht16k33Multi","doc":"A typical setup involves using the `Ht16k33` with a 7-segment display and a Raspberry Pi — such as the Raspberry Pi Zero.\n\nYou can use the [Nerves Project](https://hexdocs.pm/nerves/getting-started.html)\nto build firmware for the Raspberry Pi and other embedded systems like the BeagleBone.\nSee the [list of supported targets](https://hexdocs.pm/nerves/supported-targets.html) (Nerves Project) for more information.","ref":"Ht16k33Multi.html#module-usage"},{"type":"module","title":"Installation - Ht16k33Multi","doc":"1. **Connect the `Ht16k33` to your embedded system**.\n  See the [Connect the device to the I²C bus and power](#module-connect-the-device-to-the-i2c-bus-and-power) section for details.\n\n2. **Add the library to your dependencies**\n\n    ```elixir\n    # mix.exs\n    defp deps do\n      [\n        {:ht16k33_multi, \"~> 0.2.2\"}\n      ]\n    end\n    ```\n\n3. **Fetch the dependencies**\n\n    ```shell\n    mix deps.get\n    ```\n\n4. **Start the `Ht16k33Multi` GenServer**\n\n    You can start it manually in `iex`:\n\n    ```elixir\n    iex> Ht16k33Multi.start_link()\n    ```\n\n    Or supervise it within your application:\n\n    ```elixir\n    children = [\n      # Single device with default I²C bus (\"i2c-1\") and address (0x70)\n      Ht16k33Multi,\n\n      # OR with explicit options\n      {Ht16k33Multi, i2c_bus: \"i2c-1\", address: 0x70}\n    ]\n    ```\n\n    If you're using multiple devices (all on the default I²C bus `\"i2c-1\"`), assign each a name and address:\n\n    ```elixir\n    children = [\n      {Ht16k33Multi, name: :red_leds, address: 0x70},\n      {Ht16k33Multi, name: :blue_leds, address: 0x71},\n      {Ht16k33Multi, name: :yellow_leds, address: 0x72}\n    ]\n    ```\n\n    > #### Detect I2C Bus and Device Address {: .tip}\n    > See the [Device Address](#module-device-address) section to learn how to detect your I²C bus and device address.\n\n\n5. **Write to the display**\n\n    Display a message:\n\n    ```elixir\n    iex> Ht16k33Multi.write(\"Hola\")\n    ```\n\n    Enable blinking:\n\n    ```elixir\n    iex> Ht16k33Multi.blinking_on()\n    ```\n\n    Dim the display:\n\n    ```elixir\n    iex> Ht16k33Multi.dimming(6)\n    ```","ref":"Ht16k33Multi.html#module-installation"},{"type":"module","title":"Connect the Device to the I2C Bus and Power - Ht16k33Multi","doc":"","ref":"Ht16k33Multi.html#module-connect-the-device-to-the-i2c-bus-and-power"},{"type":"module","title":"Using Qwiic with a Raspberry Pi Zero (rpi0) - Ht16k33Multi","doc":"You can easily chain multiple `Ht16k33` devices using Qwiic cables. This allows you to have multiple displays showing full sentences or other content.","ref":"Ht16k33Multi.html#module-using-qwiic-with-a-raspberry-pi-zero-rpi0"},{"type":"module","title":"Wiring Overview: - Ht16k33Multi","doc":"| Wire Color | Function           | Raspberry Pi Zero Pin | GPIO Pin  |\n|------------|--------------------|-----------------------|-----------|\n| Black      | GND                | 6                     | GND       |\n| Red        | 3.3V               | 4                     | 5V        |\n| Blue       | SDA (Serial Data)  | 3                     | GPIO2     |\n| Yellow     | SCL (Serial Clock) | 5                     | GPIO3     |\n\n\n![HT16K33 7-segment display with I²C Qwiic connection to a Raspberry Pi Zero](assets/ht16k33-7-segment-i2c-qwiic-connection-to-rpi0.jpg)","ref":"Ht16k33Multi.html#module-wiring-overview"},{"type":"module","title":"Device Address - Ht16k33Multi","doc":"You can detect the I²C bus and device addresses using [`Circuits.I2C`](https://hexdocs.pm/circuits_i2c/Circuits.I2C.html):\n\n```elixir\niex> Circuits.I2C.bus_names()\n[\"i2c-1\"]\n\niex> Circuits.I2C.detect_devices()\nDevices on I2C bus \"i2c-1\":\n* 112  (0x70)\n1 devices detected on 1 I²C buses\n```\n\nThe device address is configurable in hardware.\nYou can set it by soldering the address pins (shown at the bottom right in the image below).\n\nSee the [HT16K33 datasheet](https://www.holtek.com/webapi/116711/HT16K33Av102.pdf) for more details.\n\n![HT16K33 7-segment backside with address pins and I²C Qwiic connection](assets/ht16k33-backside.jpg)","ref":"Ht16k33Multi.html#module-device-address"},{"type":"module","title":"Testing - Ht16k33Multi","doc":"This library has been tested with the **Adafruit 7-Segment LED HT16K33 Backpack**.","ref":"Ht16k33Multi.html#module-testing"},{"type":"function","title":"Ht16k33Multi.blinking_off/1","doc":"Sets blinking off for the 7-segment display.\n\n  * `name` – The GenServer name of the device.\n    This should match the name provided to `Ht16k33Multi.start_link/1`,\n    e.g., `Ht16k33Multi.start_link(name: :red_leds)`.","ref":"Ht16k33Multi.html#blinking_off/1"},{"type":"function","title":"Examples - Ht16k33Multi.blinking_off/1","doc":"Ht16k33Multi.blinking_off(:red_leds)","ref":"Ht16k33Multi.html#blinking_off/1-examples"},{"type":"function","title":"Ht16k33Multi.blinking_off_all/1","doc":"Sets blinking off for all displays.\n\n  * `devices_names` – A list of GenServer names that identify the displays.\n    These names should match those provided to `Ht16k33Multi.start_link/1`,\n    e.g., `[:blue_leds, :red_leds]`.\n\nThis function calls `blinking_off/1` for each device in the list,\nsetting the blinking off for all of them.","ref":"Ht16k33Multi.html#blinking_off_all/1"},{"type":"function","title":"Examples - Ht16k33Multi.blinking_off_all/1","doc":"Ht16k33Multi.blinking_off_all([:blue_leds, :red_leds])","ref":"Ht16k33Multi.html#blinking_off_all/1-examples"},{"type":"function","title":"Ht16k33Multi.blinking_on/2","doc":"Turns blinking on for the 7-segment display.\n\nThe default blinking speed is 0.5 Hz.\n\n* `speed` – The blinking speed:\n    * `0` – 0.5 Hz\n    * `1` – 1 Hz\n    * `2` – 2 Hz\n* `name` – The GenServer name of the device.\n  This should match the name provided to `Ht16k33Multi.start_link/1`,\n  e.g., `Ht16k33Multi.start_link(name: :red_leds)`.","ref":"Ht16k33Multi.html#blinking_on/2"},{"type":"function","title":"Example - Ht16k33Multi.blinking_on/2","doc":"Ht16k33Multi.blinking_on(:red_leds, 1)","ref":"Ht16k33Multi.html#blinking_on/2-example"},{"type":"function","title":"Ht16k33Multi.blinking_on_all/2","doc":"Sets blinking on for all displays.\n\n  * `devices_names` – A list of GenServer names that identify the displays.\n    These names should match those provided to `Ht16k33Multi.start_link/1`,\n    e.g., `[:blue_leds, :red_leds]`.\n  * `speed` – The blinking speed.\n    Refer to `blinking_on/2` for available speed values.\n\nThis function calls `blinking_on/2` for each device in the list,\nsetting the blinking on for all of them.","ref":"Ht16k33Multi.html#blinking_on_all/2"},{"type":"function","title":"Examples - Ht16k33Multi.blinking_on_all/2","doc":"Ht16k33Multi.blinking_on_all([:blue_leds, :red_leds], 1)","ref":"Ht16k33Multi.html#blinking_on_all/2-examples"},{"type":"function","title":"Ht16k33Multi.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Ht16k33Multi.html#child_spec/1"},{"type":"function","title":"Ht16k33Multi.colon_off/1","doc":"Sets colon off for the 7-segment display.\n\n  * `name` – The GenServer name of the device.\n    This should match the name provided to `Ht16k33Multi.start_link/1`,\n    e.g., `Ht16k33Multi.start_link(name: :red_leds)`.","ref":"Ht16k33Multi.html#colon_off/1"},{"type":"function","title":"Examples - Ht16k33Multi.colon_off/1","doc":"Ht16k33Multi.colon_off(:red_leds)","ref":"Ht16k33Multi.html#colon_off/1-examples"},{"type":"function","title":"Ht16k33Multi.colon_off_all/1","doc":"Sets colon off for all displays.\n\n  * `devices_names` – A list of GenServer names that identify the displays.\n    These names should match those provided to `Ht16k33Multi.start_link/1`,\n    e.g., `[:blue_leds, :red_leds]`.\n\nThis function calls `colon_off/1` for each device in the list,\nsetting the colon off for all of them.","ref":"Ht16k33Multi.html#colon_off_all/1"},{"type":"function","title":"Examples - Ht16k33Multi.colon_off_all/1","doc":"Ht16k33Multi.colon_off_all([:blue_leds, :red_leds])","ref":"Ht16k33Multi.html#colon_off_all/1-examples"},{"type":"function","title":"Ht16k33Multi.colon_on/1","doc":"Sets colon on for the 7-segment display.\n\n  * `name` – The GenServer name of the device.\n    This should match the name provided to `Ht16k33Multi.start_link/1`,\n    e.g., `Ht16k33Multi.start_link(name: :red_leds)`.","ref":"Ht16k33Multi.html#colon_on/1"},{"type":"function","title":"Examples - Ht16k33Multi.colon_on/1","doc":"Ht16k33Multi.colon_on(:red_leds)","ref":"Ht16k33Multi.html#colon_on/1-examples"},{"type":"function","title":"Ht16k33Multi.colon_on_all/1","doc":"Sets colon on for all displays.\n\n  * `devices_names` – A list of GenServer names that identify the displays.\n    These names should match those provided to `Ht16k33Multi.start_link/1`,\n    e.g., `[:blue_leds, :red_leds]`.\n\nThis function calls `colon_on/1` for each device in the list,\nsetting the colon on for all of them.","ref":"Ht16k33Multi.html#colon_on_all/1"},{"type":"function","title":"Examples - Ht16k33Multi.colon_on_all/1","doc":"Ht16k33Multi.colon_on_all([:blue_leds, :red_leds])","ref":"Ht16k33Multi.html#colon_on_all/1-examples"},{"type":"function","title":"Ht16k33Multi.dimming/2","doc":"Sets the dimming level (brightness) of the display.\n\nThe `value` should be an integer between 1 and 16.\n\n  * `value` – The dimming level. Must be an integer between 1 and 16.\n  * `name` – The GenServer name of the device.\n    This should match the name provided to `Ht16k33Multi.start_link/1`,\n    e.g., `Ht16k33Multi.start_link(name: :red_leds)`.","ref":"Ht16k33Multi.html#dimming/2"},{"type":"function","title":"Examples - Ht16k33Multi.dimming/2","doc":"Ht16k33Multi.dimming(8, :red_leds)","ref":"Ht16k33Multi.html#dimming/2-examples"},{"type":"function","title":"Ht16k33Multi.dimming_all/2","doc":"Dims all displays with the same value.\n\nThe `value` should be an integer between 1 and 16.\n\n  * `value` – The dimming level. Must be an integer between 1 and 16.\n  * `devices_names` – A list of GenServer names that identify the displays.\n    These names should match those provided to `Ht16k33Multi.start_link/1`,\n    e.g., `[:blue_leds, :red_leds]`.\n\nThis function calls `dimming/2` for each device in the list,\nsetting the dimming level for all of them.","ref":"Ht16k33Multi.html#dimming_all/2"},{"type":"function","title":"Examples - Ht16k33Multi.dimming_all/2","doc":"Ht16k33Multi.dimming_all(8, [:blue_leds, :red_leds])","ref":"Ht16k33Multi.html#dimming_all/2-examples"},{"type":"function","title":"Ht16k33Multi.start_link/1","doc":"Starts the `Ht16k33Multi` GenServer.","ref":"Ht16k33Multi.html#start_link/1"},{"type":"function","title":"Options - Ht16k33Multi.start_link/1","doc":"* `:name` – (optional) The GenServer name of the device.\n    Use this to run multiple GenServers for different LED displays.\n\n  * `:i2c_bus` – The name of the I²C bus (e.g., `\"i2c-1\"`).\n    Defaults to `\"i2c-1\"`.\n\n  * `:address` – The I²C address of the device (e.g., `0x70`).\n    Defaults to `0x70`.","ref":"Ht16k33Multi.html#start_link/1-options"},{"type":"function","title":"Default values - Ht16k33Multi.start_link/1","doc":"```elixir\nname: Ht16k33Multi,\ni2c_bus: \"i2c-1\",\naddress: 0x70\n```","ref":"Ht16k33Multi.html#start_link/1-default-values"},{"type":"function","title":"Examples - Ht16k33Multi.start_link/1","doc":"Start with defaults:\n\n```elixir\nHt16k33Multi.start_link()\n```\n\nStart with custom name and address:\n\n```elixir\nHt16k33Multi.start_link(name: :red_leds, address: 0x72)\n```","ref":"Ht16k33Multi.html#start_link/1-examples"},{"type":"function","title":"Ht16k33Multi.status/1","doc":"Returns the current state of the `Ht16k33Multi` GenServer.\n\n  * `name` – The GenServer name, PID, or tuple identifying the process.\n    This should match the name provided when starting the GenServer with `Ht16k33Multi.start_link/1`.","ref":"Ht16k33Multi.html#status/1"},{"type":"function","title":"Examples - Ht16k33Multi.status/1","doc":"```elixir\nHt16k33Multi.status()\nHt16k33Multi.status(:red_leds)\n```","ref":"Ht16k33Multi.html#status/1-examples"},{"type":"function","title":"Ht16k33Multi.write/2","doc":"Writes a string or integer to the 7-segment display.\n\nYou can pass more than 4 characters or digits,\nbut only the first 4 will be shown since the display has just 4 positions.\n\n  * `characters` – A string or integer to display.\n  * `name` – The GenServer name of the device.\n    This should match the name provided to `Ht16k33Multi.start_link/1`,\n    e.g., `Ht16k33Multi.start_link(name: :red_leds)`.","ref":"Ht16k33Multi.html#write/2"},{"type":"function","title":"Examples - Ht16k33Multi.write/2","doc":"Ht16k33Multi.write(\"Hola\")\n    Ht16k33Multi.write(43, :red_leds)","ref":"Ht16k33Multi.html#write/2-examples"},{"type":"function","title":"Ht16k33Multi.write_to_all/3","doc":"Writes a string of characters or an integer to multiple 7-segment displays.\n\n  * `characters` – A binary (string) or integer to display.\n  * `devices_names` – A list of GenServer names that identify the displays.\n    These names should match those provided to `Ht16k33Multi.start_link/1`,\n    e.g., `[:blue_leds, :red_leds]`.\n  * `option` – An optional keyword list of options.\n    Use `one_word_per_display: false` if you want to display characters continuously across all displays.\n\nBy default, one word (up to 4 characters) is written per display.\nWords longer than 4 characters will be truncated.\n\nIf you want to display the characters continuously across displays,\npass the option `one_word_per_display: false`.","ref":"Ht16k33Multi.html#write_to_all/3"},{"type":"function","title":"Example - Ht16k33Multi.write_to_all/3","doc":"Ht16k33Multi.write_to_all(\"Hola que tal?\", [:blue_leds, :red_leds, :yellow_leds])","ref":"Ht16k33Multi.html#write_to_all/3-example"},{"type":"module","title":"Ht16k33Multi.CircuitSimMock.Ht16k33Mock","doc":"Ht16k33 mock for testing purposes.\n\nThis module simulates the Ht16k33 device and is used in conjunction with the `CircuitsSim` library\nfor running tests without requiring real hardware.\n\nIt is configured in the `config/test.exs` file.","ref":"Ht16k33Multi.CircuitSimMock.Ht16k33Mock.html"},{"type":"function","title":"Ht16k33Multi.CircuitSimMock.Ht16k33Mock.child_spec/1","doc":"","ref":"Ht16k33Multi.CircuitSimMock.Ht16k33Mock.html#child_spec/1"},{"type":"function","title":"Ht16k33Multi.CircuitSimMock.Ht16k33Mock.new/0","doc":"","ref":"Ht16k33Multi.CircuitSimMock.Ht16k33Mock.html#new/0"},{"type":"type","title":"Ht16k33Multi.CircuitSimMock.Ht16k33Mock.t/0","doc":"","ref":"Ht16k33Multi.CircuitSimMock.Ht16k33Mock.html#t:t/0"},{"type":"module","title":"Ht16k33Multi.Display","doc":"Commands for controlling a 7-segment display using the `Ht16k33`.\n\nFor detailed information, refer to the official `Ht16k33` datasheet:\nhttps://www.holtek.com/webapi/116711/HT16K33Av102.pdf\n\nThese commands must be sent via the I2C bus to interact with the device. For example:\n\n    command = Display.blincking_off()\n    Circuits.I2C.write(ref, 0x70, < >)\n\nor\n\n    Display.blincking_off() |> I2cBus.write(%Ht16k33{} = state)\n\n  > #### use `Ht16k33Multi` {: .tip}\n  > To simplify usage, please use the `Ht16k33Multi` GenServer module,\n  > such as calling `Ht16k33Multi.blinking_on()` for ease of interaction.\n\n  > #### Display needs to be initialized {: .info}\n  > The display needs to be initialized before anything can be shown.\n  > For initialization instructions, please refer to the documentation for `Ht16k33Multi.Display.initialize/0`.","ref":"Ht16k33Multi.Display.html"},{"type":"module","title":"Display positions and colon - Ht16k33Multi.Display","doc":"The display uses specific positions to control the segments and colon:\n\n```\nPosition | A   B  :  C  D  |\n         |-----------------|\nDisplay  | 8.  8. :  8. 8. |\n```\n\n\n| Position   | Hex Register |\n|------------|--------------|\n| A          | 0x00         |\n| B          | 0x02         |\n| : (colon)  | 0x04         |\n| C          | 0x06         |\n| D          | 0x08         |","ref":"Ht16k33Multi.Display.html#module-display-positions-and-colon"},{"type":"function","title":"Ht16k33Multi.Display.all_positions/0","doc":"Retrieve all display position values as a list,\nbased on this module documentation (`Ht16k33Multi.Display`).","ref":"Ht16k33Multi.Display.html#all_positions/0"},{"type":"function","title":"Ht16k33Multi.Display.blinking_off/0","doc":"Command to turn off blinking on the display.","ref":"Ht16k33Multi.Display.html#blinking_off/0"},{"type":"function","title":"Ht16k33Multi.Display.blinking_on/1","doc":"Command to activate blinking on the display with adjustable speed.\n\nThe default blinking speed is 0.5 Hz.\n\n* `speed` – The blinking speed:\n    * `0` – 0.5 Hz\n    * `1` – 1 Hz\n    * `2` – 2 Hz","ref":"Ht16k33Multi.Display.html#blinking_on/1"},{"type":"function","title":"Ht16k33Multi.Display.clear/0","doc":"Clear the display by turning off all LED segments.","ref":"Ht16k33Multi.Display.html#clear/0"},{"type":"function","title":"Ht16k33Multi.Display.colon_off/0","doc":"Command to turn the colon off.","ref":"Ht16k33Multi.Display.html#colon_off/0"},{"type":"function","title":"Ht16k33Multi.Display.colon_on/0","doc":"Command to turn the colon on.","ref":"Ht16k33Multi.Display.html#colon_on/0"},{"type":"function","title":"Ht16k33Multi.Display.display_off/0","doc":"Command to turn the display off.","ref":"Ht16k33Multi.Display.html#display_off/0"},{"type":"function","title":"Ht16k33Multi.Display.display_on/0","doc":"Command to turn the display on.","ref":"Ht16k33Multi.Display.html#display_on/0"},{"type":"function","title":"Ht16k33Multi.Display.initialize/0","doc":"Initialize the display by enabling the oscillation, turning the display on,\nand ensuring the colon and all LED segments are off for a clean display of text.\n\nThis is required to begin displaying something on the `Ht16k33`.","ref":"Ht16k33Multi.Display.html#initialize/0"},{"type":"function","title":"Ht16k33Multi.Display.oscillation_on/0","doc":"Command to start the oscillation, which is necessary for initialization.","ref":"Ht16k33Multi.Display.html#oscillation_on/0"},{"type":"module","title":"Ht16k33Multi.Display.Blinking","doc":"Provides commands to control blinking on the entire display.\n\nYou can enable blinking at different frequencies or disable it entirely.\n\n  > #### use `Ht16k33Multi` {: .tip}\n  > To simplify usage, please use the `Ht16k33Multi` GenServer module,\n  > such as calling `Ht16k33Multi.blinking_on()` for ease of interaction.","ref":"Ht16k33Multi.Display.Blinking.html"},{"type":"function","title":"Ht16k33Multi.Display.Blinking.off/0","doc":"Returns the command to disable blinking.","ref":"Ht16k33Multi.Display.Blinking.html#off/0"},{"type":"function","title":"Ht16k33Multi.Display.Blinking.on/1","doc":"Returns the command to enable blinking at the specified speed.\n\nThe default blinking speed is 0.5 Hz.\n\nSupported `speed` values:\n  * `0` — 0.5 Hz\n  * `1` — 1 Hz\n  * `2` — 2 Hz\nAny other value defaults to 2 Hz.","ref":"Ht16k33Multi.Display.Blinking.html#on/1"},{"type":"module","title":"Ht16k33Multi.Display.Dimming","doc":"Module for setting the dimming level (brightness) of the Ht16k33 display.\n\nThe Ht16k33 supports setting the dimming level, but it does not support reading it back.\n\n  > #### use `Ht16k33Multi` {: .tip}\n  > To simplify usage, please use the `Ht16k33Multi` GenServer module,\n  > such as calling `Ht16k33Multi.dimming(6)` for ease of interaction.","ref":"Ht16k33Multi.Display.Dimming.html"},{"type":"module","title":"Dimming Command Format - Ht16k33Multi.Display.Dimming","doc":"Dimming command\n    --------------------------\n         command | pulse width\n    set  1 1 1 0   P3 P2 P1 P0\n          (0xE)    (0x0 to 0xF)\n\n    Pulse width | Hex value command\n    -------------------------------\n    1/16duty      <<0xE0>>\n    [...]\n    16/16duty     <<0xEF>>","ref":"Ht16k33Multi.Display.Dimming.html#module-dimming-command-format"},{"type":"function","title":"Ht16k33Multi.Display.Dimming.set/1","doc":"Sets the dimming level of the display.\n\nAccepts values between 1 and 16, where 1 is the lowest brightness and 16 is the highest.\nValues below 1 are clamped to 1, and values above 16 are clamped to 16.","ref":"Ht16k33Multi.Display.Dimming.html#set/1"},{"type":"module","title":"Ht16k33Multi.Font","doc":"Font for the `Ht16k33` 7-segment display.\nThis module converts characters into segment data for the display.","ref":"Ht16k33Multi.Font.html"},{"type":"module","title":"Command Structure for the 7-Segment Display - Ht16k33Multi.Font","doc":"One position on the 7-segment display:\n\n            1\n           ___\n      (2) |   | 2\n      (4)  ---\n      (1) |   | 4\n           ---  * (8)\n            8\n\nWhere:\n- `(x)` represents the first hex value\n- `x` represents the last hex value","ref":"Ht16k33Multi.Font.html#module-command-structure-for-the-7-segment-display"},{"type":"module","title":"Examples: - Ht16k33Multi.Font","doc":"- For the character \"0\", the segments (2), (1) (= 3) and segments 1, 2, 4, 8 (= 15 = hex F) are lit. This corresponds to the hex value `0x3F`.\n- For the character \"4\", the segments (2), (4) (= 6) and segments 2, 4 (= 6) are lit. This corresponds to the hex value `0x66`.","ref":"Ht16k33Multi.Font.html#module-examples"},{"type":"module","title":"Segment Hex Mappings: - Ht16k33Multi.Font","doc":"|      | SEGMENTS_ON |\n| HEX  |  8  4  2  1 |\n|------|-------------|\n| 0    |  0  0  0  0 |\n| 1    |  0  0  0  1 |\n| 2    |  0  0  1  0 |\n| 3    |  0  0  1  1 |\n| 4    |  0  1  0  0 |\n| 5    |  0  1  0  1 |\n| 6    |  0  1  1  0 |\n| 7    |  0  1  1  1 |\n| 8    |  1  0  0  0 |\n| 9    |  1  0  0  1 |\n| A    |  1  0  1  0 |\n| B    |  1  0  1  1 |\n| C    |  1  1  0  0 |\n| D    |  1  1  0  1 |\n| E    |  1  1  1  0 |\n| F    |  1  1  1  1 |","ref":"Ht16k33Multi.Font.html#module-segment-hex-mappings"},{"type":"function","title":"Ht16k33Multi.Font.segments/1","doc":"Converts characters or integers to their corresponding hexadecimal values\nfor displaying the correct segments on a 7-segment display.\nFor example, the letter \"A\" is displayed with the command `0x77`.\n\nThis function returns the hexadecimal segment commands for a string of characters\nor an integer to be displayed on the 7-segment display.","ref":"Ht16k33Multi.Font.html#segments/1"},{"type":"module","title":"Ht16k33Multi.Font.Ar7segmentFont","doc":"Provides the `AR-7-segment-font` used for rendering characters on a 7-segment display.\n\nFor details on how this font is applied, see the `Ht16k33Multi.Font` module documentation.","ref":"Ht16k33Multi.Font.Ar7segmentFont.html"},{"type":"function","title":"Ht16k33Multi.Font.Ar7segmentFont.map/0","doc":"Returns a map representing the `AR-7-segment` font.\n\nThe map contains the binary encoding for each character, which corresponds to the byte values\nused to display on a 7-segment display.","ref":"Ht16k33Multi.Font.Ar7segmentFont.html#map/0"},{"type":"module","title":"Ht16k33Multi.I2cBus","doc":"Provides a simplified interface for sending I2C messages to the `Ht16k33` display driver.\n\nThis module abstracts away low-level I2C interactions and provides helper functions to\nopen a bus and write commands using the `%Ht16k33Multi{}` struct.","ref":"Ht16k33Multi.I2cBus.html"},{"type":"module","title":"Background - Ht16k33Multi.I2cBus","doc":"The `Ht16k33` chip receives binary commands over the I2C bus to control LED displays such\nas 7-segment digits. Each command consists of a position address and a segment value.","ref":"Ht16k33Multi.I2cBus.html#module-background"},{"type":"module","title":"Manual Command Example - Ht16k33Multi.I2cBus","doc":"To display the character \"A\" manually via `Circuits.I2C`:\n\n    iex> i2c_bus = \"i2c-1\"\n    iex> address = 0x70\n    iex> position = 0x00\n    iex> command = 0x77 # Segment pattern for \"A\"\n    iex> {:ok, i2c_ref} = Circuits.I2C.open(i2c_bus)\n    iex> Circuits.I2C.write(i2c_ref, address, < >)\n\nYou can inspect available buses and devices:\n\n    iex> Circuits.I2C.bus_names()\n    [\"i2c-1\"]\n\n    iex> Circuits.I2C.detect_devices()\n    Devices on I2C bus \"i2c-1\":\n    * 112 (0x70)\n\n  > #### Display needs to be initialized {: .info}\n  > The display needs to be initialized before anything can be shown.\n  > For initialization instructions, please refer to the documentation for `Ht16k33Multi.Display.initialize/0`.","ref":"Ht16k33Multi.I2cBus.html#module-manual-command-example"},{"type":"module","title":"Using This Module - Ht16k33Multi.I2cBus","doc":"This module streamlines communication by accepting bitstrings, integers, or lists of commands:\n\n    iex> {:ok, i2c_ref} = Ht16k33Multi.I2cBus.open(\"i2c-1\")\n    iex> ht16k33 = %Ht16k33Multi{address: 0x70, i2c_ref: i2c_ref}\n    iex> Ht16k33Multi.I2cBus.write(<<0x00, 0x77>>, ht16k33)\n\nThe latest command and status are stored in the `:last_command` field of the struct.","ref":"Ht16k33Multi.I2cBus.html#module-using-this-module"},{"type":"function","title":"Ht16k33Multi.I2cBus.open/1","doc":"Opens the specified I2C bus.\n\nThis function uses Circuits.I2C.open/1 to establish a connection to the\nI2C bus identified by i2c_bus.\n\n* `i2c_bus` - The name of the I2C bus to open as a string.","ref":"Ht16k33Multi.I2cBus.html#open/1"},{"type":"function","title":"Examples - Ht16k33Multi.I2cBus.open/1","doc":"iex> Ht16k33Multi.I2cBus.open(\"i2c-1\")\n    {:ok, #Reference<...>}\n\n    iex> Ht16k33Multi.I2cBus.open(\"invalid-bus\")\n    {:error, :enodev}","ref":"Ht16k33Multi.I2cBus.html#open/1-examples"},{"type":"function","title":"Ht16k33Multi.I2cBus.write/2","doc":"Writes a command or a series of commands to the Ht16k33 device.\n\nThis function sends data over the I2C bus to the Ht16k33 device specified\nin the `%Ht16k33{}` struct. It can handle single byte commands, multi-byte\ncommands as bitstrings, or a list of commands to be sent sequentially.\n\nThe `%Ht16k33{}` struct is expected to contain the I2C device reference\n(obtained from open/1) and the I2C address of the Ht16k33 device.\n\n* `command` - The command(s) to send to the device\n   as a `bitstring()`, `integer()`, or a `list()` of `bitstring()`s or `integer()`s.\n* `ht16k33` - The `%Ht16k33Multi{}` struct containing\n  the I2C device reference and the device address.\n\nIt returns the updated `%Ht16k33Multi{}` struct with the command that was sent\nand the exit_status of the write operation:\n\n  > 💡 **Note**: The display needs to be initialized before anything can be shown.\n  For initialization instructions, please refer to the documentation for `Ht16k33Multi.Display.initialize/0`.","ref":"Ht16k33Multi.I2cBus.html#write/2"},{"type":"function","title":"Examples - Ht16k33Multi.I2cBus.write/2","doc":"Sending a single byte command:\n\n    iex> {:ok, i2c_ref} = Ht16k33Multi.I2cBus.open(\"i2c-1\")\n    iex> ht16k33 = %Ht16k33Multi{address: 0x70, i2c_ref: i2c_ref}\n    iex> Ht16k33Multi.I2cBus.write(0x81, ht16k33) # Example: Trun on the display\n    %Ht16k33Multi{address: 0x70, command: <<129>>, exit_status: :ok, i2c_ref: #Reference<...>}\n\nSending a multi-byte command as a bitstring:\n\n    iex> {:ok, i2c_ref} = Ht16k33Multi.I2cBus.open(\"i2c-1\")\n    iex> ht16k33 = %Ht16k33Multi{address: 0x70, i2c_ref: i2c_ref}\n    iex> Ht16k33Multi.I2cBus.write(<<0x00, 0x77>>, ht16k33) # Example: Display \"A\" at position 0\n    %Ht16k33Multi{address: 0x70, command: <<0, 119>>, exit_status: :ok, i2c_ref: #Reference<...>}\n\nSending a list of commands:\n\n    iex> {:ok, i2c_ref} = Ht16k33Multi.I2cBus.open(\"i2c-1\")\n    iex> ht16k33 = %Ht16k33Multi{address: 0x70, i2c_ref: i2c_ref}\n    iex> commands = [0x81, <<0x00, 0x77>>]\n    iex> Ht16k33Multi.I2cBus.write(commands, ht16k33)\n    %Ht16k33Multi{address: 0x70, command: <<0, 119>>, exit_status: :ok, i2c_ref: #Reference<...>}","ref":"Ht16k33Multi.I2cBus.html#write/2-examples"},{"type":"module","title":"Ht16k33Multi.MultiDevices","doc":"Provides functionality for writing to multiple 7-segment displays at once.\n\nThis module handles the coordination and distribution of characters across multiple `Ht16k33` 7-segment displays.\nIt allows you to split a string into segments that can be shown on multiple displays.\nIt is especially useful when you want to render full words or sentences across a chain of displays connected\nvia I2C, each capable of showing up to 4 characters.","ref":"Ht16k33Multi.MultiDevices.html"},{"type":"module","title":"Usage - Ht16k33Multi.MultiDevices","doc":"> #### use `Ht16k33Multi` {: .tip}\n  > To simplify usage, please use the `Ht16k33Multi` GenServer module,\n  > such as calling `Ht16k33Multi.write_to_all/3` for ease of interaction.\n\n\nEach display should be started with a unique name using `Ht16k33Multi.start_link(name: :device_name)`.\nYou can then pass a list of these device names to `split_for_devices/3` to split a string and map it to the appropriate display.\n\nExample:\n\n    iex> Ht16k33Multi.MultiDevices.split_for_devices(\"Hola que tal?\", [:blue_leds, :red_leds, :green_leds])\n    [blue_leds: \"Hola\", red_leds: \"que\", green_leds: \"tal?\"]\n\nThe resulting keyword list can be piped into display writing functions:\n\n    iex> Ht16k33Multi.MultiDevices.split_for_devices(\"Hola que tal?\", [:blue_leds, :red_leds, :green_leds])\n    |> Enum.map(fn {device, chars} -> Ht16k33Multi.write(chars, device) end)","ref":"Ht16k33Multi.MultiDevices.html#module-usage"},{"type":"function","title":"Ht16k33Multi.MultiDevices.split_for_devices/3","doc":"Splits the given character string into chunks and builds a keyword list\nmapping each device name to a segment of characters.\n\n  - `characters`: A string to be displayed across multiple devices.\n  - `devices_names`: A list of GenServer names, as passed to `Ht16k33Multi.start_link/1`.\n  - `options`: Currently supports:\n    - `:one_word_per_display` (default: `true`): If true, splits the string into words (max 4 characters each).\n      If false, the string is split into 4-character chunks continuously.\n\n  > 💡 **Note:** Each display supports up to 4 characters. If more chunks than device names are present,\n  extra chunks will be ignored. If fewer chunks are provided, blank segments will be appended.","ref":"Ht16k33Multi.MultiDevices.html#split_for_devices/3"},{"type":"function","title":"Examples - Ht16k33Multi.MultiDevices.split_for_devices/3","doc":"iex> Ht16k33Multi.MultiDevices.split_for_devices(\"Hola que tal?\", [:blue_leds, :red_leds, :green_leds])\n    [blue_leds: \"Hola\", red_leds: \"que\", green_leds: \"tal?\"]","ref":"Ht16k33Multi.MultiDevices.html#split_for_devices/3-examples"},{"type":"module","title":"Ht16k33Multi.Write","doc":"Prepares display data by combining character segments with their corresponding positions.\n\nEach 7-segment display has 4 character positions, each with its own memory address,\nsee `Ht16k33Multi.Display`.\nThis module maps each character to the appropriate segment representation and assigns it\nto the correct position address. It outputs the data format expected by the `Ht16k33` device\nfor writing via the I2C bus.\n\n  > #### use `Ht16k33Multi` {: .tip}\n  > To simplify usage, please use the `Ht16k33Multi` GenServer module,\n  > such as calling `Ht16k33Multi.write/1` for ease of interaction.","ref":"Ht16k33Multi.Write.html"},{"type":"function","title":"Ht16k33Multi.Write.to_display/1","doc":"Converts a string or integer into a list of 7-segment display commands.\n\nThe characters are transformed using the `Font` module into segment codes,\nand each of the first 4 characters is paired with a display position.\nIf fewer than 4 characters are provided, the remaining positions are padded with spaces.\nIf more than 4 characters are provided, the excess characters are discarded.\n\nThe output is a list of bitstrings formatted for writing to the display using the `I2cBus` module.\n\n  > #### use `Ht16k33Multi` {: .tip}\n  > To simplify usage, please use the `Ht16k33Multi` GenServer module,\n  > such as calling `Ht16k33Multi.write/1` for ease of interaction.","ref":"Ht16k33Multi.Write.html#to_display/1"},{"type":"function","title":"Example - Ht16k33Multi.Write.to_display/1","doc":"iex> i2c_bus = \"i2c-1\"\n    iex> {:ok, i2c_ref} = Circuits.I2C.open(i2c_bus)\n    iex> name = :red_leds\n    iex> address = 0x70\n    iex> Ht16k33Multi.Write.to_display(\"Hi 1\")\n    ...> |> Ht16k33Multi.I2cBus.write(%Ht16k33Multi{name: name, i2c_ref: i2c_ref, address: address})","ref":"Ht16k33Multi.Write.html#to_display/1-example"},{"type":"extras","title":"Ht16k33Multi","doc":"# Ht16k33Multi\n\n[![Build Status](https://github.com/alexisruccius/ht16k33_multi/workflows/CI/badge.svg)](https://github.com/alexisruccius/ht16k33_multi/actions/workflows/CI.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/ht16k33_multi.svg)](https://hex.pm/packages/ht16k33_multi)\n[![API docs](https://img.shields.io/hexpm/v/ht16k33_multi.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/ht16k33_multi)\n\n`Ht16k33Multi` is a library for controlling one or more `Ht16k33` microchips,\nwhich are commonly used to drive 7-segment displays, such as these shown below:\n\n![Image of Ht16k33 7-segment display](assets/ht16k33multi-7-segment-love-elixir.jpg)\n\nThe docs can be found at  .","ref":"readme.html"},{"type":"extras","title":"Features - Ht16k33Multi","doc":"The main features of `Ht16k33Multi` include:\n\n- Displaying numbers on a 7-segment display\n- Displaying words using a special 7-segment font\n- Supporting multiple displays (hence the \"multi\" in the library name).\n  You can easily chain multiple `Ht16k33` devices to display full sentences or other content across them.\n- Utilizing the built-in blinking and dimming features of the `Ht16k33` microchip","ref":"readme.html#features"},{"type":"extras","title":"Usage - Ht16k33Multi","doc":"A typical setup involves using the `Ht16k33` with a 7-segment display and a Raspberry Pi — such as the Raspberry Pi Zero.\n\nYou can use the [Nerves Project](https://hexdocs.pm/nerves/getting-started.html)\nto build firmware for the Raspberry Pi and other embedded systems like the BeagleBone.\nSee the [list of supported targets](https://hexdocs.pm/nerves/supported-targets.html) (Nerves Project) for more information.","ref":"readme.html#usage"},{"type":"extras","title":"Installation - Ht16k33Multi","doc":"1. **Connect the `Ht16k33` to your embedded system**.\n  See the [Connect the device to the I²C bus and power](#connect-the-device-to-the-i2c-bus-and-power) section for details.\n\n2. **Add the library to your dependencies**\n\n    ```elixir\n    # mix.exs\n    defp deps do\n      [\n        {:ht16k33_multi, \"~> 0.2.2\"}\n      ]\n    end\n    ```\n\n3. **Fetch the dependencies**\n\n    ```shell\n    mix deps.get\n    ```\n\n4. **Start the `Ht16k33Multi` GenServer**\n\n    You can start it manually in `iex`:\n\n    ```elixir\n    iex> Ht16k33Multi.start_link()\n    ```\n\n    Or supervise it within your application:\n\n    ```elixir\n    children = [\n      # Single device with default I²C bus (\"i2c-1\") and address (0x70)\n      Ht16k33Multi,\n\n      # OR with explicit options\n      {Ht16k33Multi, i2c_bus: \"i2c-1\", address: 0x70}\n    ]\n    ```\n\n    If you're using multiple devices (all on the default I²C bus `\"i2c-1\"`), assign each a name and address:\n\n    ```elixir\n    children = [\n      {Ht16k33Multi, name: :red_leds, address: 0x70},\n      {Ht16k33Multi, name: :blue_leds, address: 0x71},\n      {Ht16k33Multi, name: :yellow_leds, address: 0x72}\n    ]\n    ```\n\n\n      > #### Detect I2C Bus and Device Address {: .tip}\n      > See the [Device Address](#device-address) section to learn how to detect your I²C bus and device address.\n\n5. **Write to the display**\n\n    Display a message:\n\n    ```elixir\n    iex> Ht16k33Multi.write(\"Hola\")\n    ```\n\n    Enable blinking:\n\n    ```elixir\n    iex> Ht16k33Multi.blinking_on()\n    ```\n\n    Dim the display:\n\n    ```elixir\n    iex> Ht16k33Multi.dimming(6)\n    ```","ref":"readme.html#installation"},{"type":"extras","title":"Connect the Device to the I2C Bus and Power - Ht16k33Multi","doc":"","ref":"readme.html#connect-the-device-to-the-i2c-bus-and-power"},{"type":"extras","title":"Using Qwiic with a Raspberry Pi Zero (rpi0) - Ht16k33Multi","doc":"You can easily chain multiple `Ht16k33` devices using Qwiic cables. This allows you to have multiple displays showing full sentences or other content.","ref":"readme.html#using-qwiic-with-a-raspberry-pi-zero-rpi0"},{"type":"extras","title":"Wiring Overview: - Ht16k33Multi","doc":"| Wire Color | Function           | Raspberry Pi Zero Pin | GPIO Pin  |\n|------------|--------------------|-----------------------|-----------|\n| Black      | GND                | 6                     | GND       |\n| Red        | 3.3V               | 4                     | 5V        |\n| Blue       | SDA (Serial Data)  | 3                     | GPIO2     |\n| Yellow     | SCL (Serial Clock) | 5                     | GPIO3     |\n\n\n![HT16K33 7-segment display with I²C Qwiic connection to a Raspberry Pi Zero](assets/ht16k33-7-segment-i2c-qwiic-connection-to-rpi0.jpg)","ref":"readme.html#wiring-overview"},{"type":"extras","title":"Device Address - Ht16k33Multi","doc":"You can detect the I²C bus and device addresses using [`Circuits.I2C`](https://hexdocs.pm/circuits_i2c/Circuits.I2C.html):\n\n```elixir\niex> Circuits.I2C.bus_names()\n[\"i2c-1\"]\n\niex> Circuits.I2C.detect_devices()\nDevices on I2C bus \"i2c-1\":\n* 112  (0x70)\n1 devices detected on 1 I²C buses\n```\n\nThe device address is configurable in hardware.\nYou can set it by soldering the address pins (shown at the bottom right in the image below).\n\nSee the [HT16K33 datasheet](https://www.holtek.com/webapi/116711/HT16K33Av102.pdf) for more details.\n\n![HT16K33 7-segment backside with address pins and I²C Qwiic connection](assets/ht16k33-backside.jpg)","ref":"readme.html#device-address"},{"type":"extras","title":"Testing - Ht16k33Multi","doc":"This library has been tested with the **Adafruit 7-Segment LED HT16K33 Backpack**.","ref":"readme.html#testing"},{"type":"extras","title":"Documentation - Ht16k33Multi","doc":"The docs can be found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.2 (2025-05-25) - Changelog","doc":"","ref":"changelog.html#v0-2-2-2025-05-25"},{"type":"extras","title":"Fixed - Changelog","doc":"- Resolved issue with incorrect dependency fetching.","ref":"changelog.html#fixed"},{"type":"extras","title":"v0.2.1 (2025-05-24) - Changelog","doc":"","ref":"changelog.html#v0-2-1-2025-05-24"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed a bug where the initial `Ht16k33Multi` GenServer start did not clear all LED segments.\nThe display now correctly initializes via `Ht16k33Multi.Display.initialize/0`.","ref":"changelog.html#fixed"},{"type":"extras","title":"v0.2.0 (2025-05-19) - Changelog","doc":"","ref":"changelog.html#v0-2-0-2025-05-19"},{"type":"extras","title":"Enhancements - Changelog","doc":"- `colon_on/1`: Enables the colon LED on a specific display.\n- `colon_off/1`: Disables the colon LED on a specific display.\n- `colon_on_all/1`: Enables the colon LED on all connected displays.\n- `colon_off_all/1`: Disables the colon LED on all connected displays.\n\nThese new functions make it easier to control the colon segment on HT16K33-driven 7-segment displays, useful for time layouts.\n\n---\n\nFor full documentation and usage examples, visit [HexDocs](https://hexdocs.pm/ht16k33_multi)","ref":"changelog.html#enhancements"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}